==> haskell-hspec-wai-json-0.11.0-562-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-1wYipUN6ugh5TZQgpIKPpb
key:                  hspec-wai-json-0.11.0-1wYipUN6ugh5TZQgpIKPpb
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  64f657112953501d410fbc2b8d9f6e37
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-1wYipUN6ugh5TZQgpIKPpb
depends:
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi
    aeson-qq-0.8.4-YrJFmdxcnQIEklEWCqNYu base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3jbMOlKTiDn4NCqaBZ47Ne
    hspec-wai-0.11.1-13n0Y8Ta2sW5n1S90VvtFA template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.11.0-569-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-GHcvvzIrNIgKfA2dEK6kYI
key:                  hspec-wai-json-0.11.0-GHcvvzIrNIgKfA2dEK6kYI
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  8c3d8962c39e5fb7d1d127a0613e2de5
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-GHcvvzIrNIgKfA2dEK6kYI
depends:
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY
    aeson-qq-0.8.4-3dpejldcxr65LxnfGZBmJv base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FUjVpmJeiVFCvFoDLJPawp
    hspec-wai-0.11.1-LsnOufd8NEH9KQNKEwnB1 template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
